@@ -246,8 +246,10 @@ class BaseIdentityPlugin(plugin.BaseAuthPlugin):
             # for example a "v2" path from http://host/admin should resolve as
             # http://host/admin/v2 where it would otherwise be host/v2.
             # This has no effect on absolute urls returned from url_for.
-            url_for = disc.url_for(version, **allow)
-            url = urllib.parse.urljoin(hacked_url.rstrip('/') + '/', url_for)
+            url = disc.url_for(version, **allow)
+
+            if url:
+                url = urllib.parse.urljoin(hacked_url.rstrip('/') + '/', url)
 
         return url
 
@@ -326,7 +328,7 @@ class BaseIdentityPlugin(plugin.BaseAuthPlugin):
         As part of the get_cache_id requirement we need to determine what
         aspects of this plugin and its values that make up the unique elements.
 
-        This should be overriden by plugins that wish to allow caching.
+        This should be overridden by plugins that wish to allow caching.
 
         :returns: The unique attributes and values of this plugin.
         :rtype: A flat dict with a str key and str or None value. This is
